@@ -25,7 +25,7 @@ sub make {
                 $mhead->{'message-id'} =~ /\A[<]\w{7}[-]\w{6}[-]\w{2}[@]/;
     $match++ if $mhead->{'subject'} =~ qr{(?:
          Mail[ ]delivery[ ]failed(:[ ]returning[ ]message[ ]to[ ]sender)?
-        |Warning:[ ]message[ ].+[ ]delayed[ ]+
+        |Warning:[ ]message[ ][^ ]+[ ]delayed[ ]+
         |Delivery[ ]Status[ ]Notification
         |Mail[ ]failure
         |Message[ ]frozen
@@ -40,7 +40,7 @@ sub make {
         # deliver.c:6424|"------ This is a copy of the message, including all the headers. ------\n");
         # deliver.c:6425|          else fprintf(f,
         # deliver.c:6426|"------ This is a copy of the message's headers. ------\n");
-         [-]+[ ]This[ ]is[ ]a[ ]copy[ ]of[ ](?:the|your)[ ]message.+?headers[.][ ][-]+
+         [-]+[ ]This[ ]is[ ]a[ ]copy[ ]of[ ](?:the|your)[ ]message,[ ]including[ ]all[ ]the[ ]headers[.][ ][-]+
         |Content-Type:[ ]*message/rfc822\n(?:[\s\t]+.*?\n\n)?
         )
     }msx;
@@ -68,11 +68,11 @@ sub make {
              This[ ]message[ ]was[ ]created[ ]automatically[ ]by[ ]mail[ ]delivery[ ]software[.]
             |A[ ]message[ ]that[ ]you[ ]sent[ ]was[ ]rejected[ ]by[ ]the[ ]local[ ]scannning[ ]code
             |A[ ]message[ ]that[ ]you[ ]sent[ ]contained[ ]one[ ]or[ ]more[ ]recipient[ ]addresses[ ]
-            |Message[ ].+[ ](?:has[ ]been[ ]frozen|was[ ]frozen[ ]on[ ]arrival)
-            |The[ ].+[ ]router[ ]encountered[ ]the[ ]following[ ]error[(]s[)]:
+            |Message[ ][^ ]+[ ](?:has[ ]been[ ]frozen|was[ ]frozen[ ]on[ ]arrival)
+            |The[ ][^ ]+[ ]router[ ]encountered[ ]the[ ]following[ ]error[(]s[)]:
             )
         }x,
-        'frozen'  => qr/\AMessage .+ (?:has been frozen|was frozen on arrival)/,
+        'frozen'  => qr/\AMessage [^ ]+ (?:has been frozen|was frozen on arrival)/,
     };
     state $recommands = [
         # transports/smtp.c:564|  *message = US string_sprintf("SMTP error from remote mail server after %s%s: "
@@ -276,7 +276,7 @@ sub make {
                     } else {
                         # Error message when email address above does not include '@'
                         # and domain part.
-                        if( $e =~ m<\A[ ]+pipe[ ]to[ ][|]/.+> ) {
+                        if( $e =~ m<\A[ ]+pipe[ ]to[ ][|]/[^ ]+> ) {
                             # pipe to |/path/to/prog ...
                             #   generated by kijitora@example.com
                             $v->{'diagnosis'} = $e;
