@@ -16,7 +16,7 @@ sub match {
 
     state $regex = qr{(?>
          access[ ]denied[.][ ]ip[ ]name[ ]lookup[ ]failed
-        |access[ ]from[ ]ip[ ]address[ ].+[ ]blocked
+        |access[ ]from[ ]ip[ ]address[ ][^ ]+[ ]blocked
         |all[ ]mail[ ]servers[ ]must[ ]have[ ]a[ ]ptr[ ]record[ ]with[ ]a[ ]valid[ ]reverse[ ]dns[ ]entry
         |bad[ ](:?dns[ ]ptr[ ]resource[ ]record|sender[ ]ip[ ]address)
         |banned[ ]sending[ ]ip  # Office365
@@ -29,7 +29,7 @@ sub match {
             |resolve[ ]your[ ]address
             )
         |client[ ]host[ ](?:
-             .+[ ]blocked[ ]using
+             [^ ]+[ ]blocked[ ]using
             |rejected:[ ](?:
                  abus[ ]detecte[ ]gu_eib_0[24]      # SFR
                 |cannot[ ]find[ ]your[ ]hostname    # Yahoo!
@@ -46,22 +46,22 @@ sub match {
            )
         |connections[ ](?:
              not[ ]accepted[ ]from[ ]ip[ ]addresses[ ]on[ ]spamhaus[ ]xbl
-            |will[ ]not[ ]be[ ]accepted[ ]from[ ].+because[ ]the[ ]ip[ ]is[ ]in[ ]spamhaus's[ ]list
+            |will[ ]not[ ]be[ ]accepted[ ]from[ ][^ ]+,[ ]because[ ]the[ ]ip[ ]is[ ]in[ ]spamhaus's[ ]list
             )
         |currently[ ]sending[ ]spam[ ]see:[ ]
         |domain[ ](?:
-             .+[ ]mismatches[ ]client[ ]ip
+             [^ ]+[ ]mismatches[ ]client[ ]ip
             |does[ ]not[ ]exist:
             )
-        |dns[ ]lookup[ ]failure:[ ].+[ ]try[ ]again[ ]later
+        |dns[ ]lookup[ ]failure:[ ][^ ]+[ ]try[ ]again[ ]later
         |dnsbl:attrbl
         |dynamic/zombied/spam[ ]ips[ ]blocked
-        |email[ ]blocked[ ]by[ ](?:.+[.]barracudacentral[.]org|spamhaus)
+        |email[ ]blocked[ ]by[ ](?:[^ ]+[.]barracudacentral[.]org|spamhaus)
         |esmtp[ ]not[ ]accepting[ ]connections  # icloud.com
-        |fix[ ]reverse[ ]dns[ ]for[ ].+
+        |fix[ ]reverse[ ]dns[ ]for[ ][^ ]+
         |go[ ]away
         |helo[ ]command[ ]rejected:
-        |host[ ].+[ ]refused[ ]to[ ]talk[ ]to[ ]me:[ ]\d+[ ]blocked
+        |host[ ][^ ]+[ ]refused[ ]to[ ]talk[ ]to[ ]me:[ ]\d+[ ]blocked
         |hosts[ ]with[ ]dynamic[ ]ip
         |http://(?:
              spf[.]pobox[.]com/why[.]html
@@ -72,17 +72,17 @@ sub match {
         |ip[/]domain[ ]reputation[ ]problems
         |ips[ ]with[ ]missing[ ]ptr[ ]records
         |is[ ](?:
-             in[ ]a[ ]black[ ]list[ ]at[ ].+[.]
-            |in[ ]an[ ].*rbl[ ]on[ ].+
+             in[ ]a[ ]black[ ]list[ ]at[ ][^ ]+[.]
+            |in[ ]an[ ][^ ]+rbl[ ]on[ ][^ ]+
             |not[ ]allowed[ ]to[ ]send[ ](?:
                  mail[ ]from
-                |from[ ].+[ ]per[ ]it's[ ]spf[ ]record
+                |from[ ][<][^ ]+[>][ ]per[ ]it's[ ]spf[ ]record
                 )
             )
-        |mail[ ]server[ ]at[ ].+[ ]is[ ]blocked
+        |mail[ ]server[ ]at[ ][^ ]+[ ]is[ ]blocked
         |mail[ ]from[ ]\d+[.]\d+[.]\d+[.]\d[ ]refused:
-        |message[ ]from[ ].+[ ]rejected[ ]based[ ]on[ ]blacklist
-        |messages[ ]from[ ].+[ ]temporarily[ ]deferred[ ]due[ ]to[ ]user[ ]complaints   # Yahoo!
+        |message[ ]from[ ][^ ]+[ ]rejected[ ]based[ ]on[ ]blacklist
+        |messages[ ]from[ ][^ ]+[ ]temporarily[ ]deferred[ ]due[ ]to[ ]user[ ]complaints   # Yahoo!
         |no[ ](?:
              access[ ]from[ ]mail[ ]server
             |ptr[ ]record[ ]found[.]
@@ -99,17 +99,17 @@ sub match {
         |reverse[ ]dns[ ](?:
               failed
              |required
-             |lookup[ ]for[ ]host[ ].+[ ]failed[ ]permanently
+             |lookup[ ]for[ ]host[ ][^ ]+[ ]failed[ ]permanently
              )
         |sender[ ]ip[ ](?:
              address[ ]rejected
             |reverse[ ]lookup[ ]rejected
             )
         |server[ ]access[ ](?:
-             .+[ ]forbidden[ ]by[ ]invalid[ ]rdns[ ]record[ ]of[ ]your[ ]mail[ ]server
+             [^ ]+[ ]forbidden[ ]by[ ]invalid[ ]rdns[ ]record[ ]of[ ]your[ ]mail[ ]server
             |forbidden[ ]by[ ]your[ ]ip[ ]
             )
-        |server[ ]ip[ ].+[ ]listed[ ]as[ ]abusive
+        |server[ ]ip[ ][^ ]+[ ]listed[ ]as[ ]abusive
         |service[ ]not[ ]available,[ ]closing[ ]transmission[ ]channel
         |service[ ]permits[ ]\d+[ ]unverifyable[ ]sending[ ]ips
         |smtp[ ]error[ ]from[ ]remote[ ]mail[ ]server[ ]after[ ]initial[ ]connection:   # Exim
@@ -118,25 +118,25 @@ sub match {
             |your[ ]remotehost[ ]looks[ ]suspiciously[ ]like[ ]spammer
             )
         |spf[ ](?:
-             .+[ ]domain[ ]authentication[ ]fail
+             [(]sender[ ]policy[ ]framework[)][ ]domain[ ]authentication[ ]fail
             |record
             |check:[ ]fail
             )
-        |spf:[ ].+[ ]is[ ]not[ ]allowed[ ]to[ ]send[ ]mail.+[a-z]{3}.+401
-        |the[ ](?:email|domain|ip).+[ ]is[ ]blacklisted
+        |spf:[ ][^ ]+[ ]is[ ]not[ ]allowed[ ]to[ ]send[ ]mail[.][ ][a-z0-9]_401
+        |the[ ](?:email|domain|ip)[ ][^ ]+[ ]is[ ]blacklisted
         |this[ ]system[ ]will[ ]not[ ]accept[ ]messages[ ]from[ ]servers[/]devices[ ]with[ ]no[ ]reverse[ ]dns
         |too[ ]many[ ](?:
              spams[ ]from[ ]your[ ]ip  # free.fr
             |unwanted[ ]messages[ ]have[ ]been[ ]sent[ ]from[ ]the[ ]following[ ]ip[ ]address[ ]above
             )
         |unresolvable[ ]relay[ ]host[ ]name
-        |veuillez[ ]essayer[ ]plus[ ]tard.+[a-z]{3}.+(?:103|510)
+        |veuillez[ ]essayer[ ]plus[ ]tard[.][ ]service[ ]refused,[ ]please[ ]try[ ]later[.][ ][0-9a-z_]+(?:103|510)
         |your[ ](?:
              network[ ]is[ ]temporary[ ]blacklisted
-            |sender's[ ]ip[ ]address[ ]is[ ]listed[ ]at[ ].+[.]abuseat[.]org
+            |sender's[ ]ip[ ]address[ ]is[ ]listed[ ]at[ ][^ ]+[.]abuseat[.]org
             |server[ ]requires[ ]confirmation
             )
-        |was[ ]blocked[ ]by[ ].+
+        |was[ ]blocked[ ]by[ ][^ ]+
         |we[ ]do[ ]not[ ]accept[ ]mail[ ]from[ ](?: # @mail.ru
              dynamic[ ]ips
             |hosts[ ]with[ ]dynamic[ ]ip[ ]or[ ]generic[ ]dns[ ]ptr-records
@@ -222,7 +222,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2019 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2020 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
